CommandLog class

Annotations
  • @freezed

Constructors

CommandLog({required String command, required String logStdout, required String logStderr, required int createdAt, required int exitCode})
const
factory
CommandLog.fromJson(Map<String, Object?> json)
factory

Properties

command → String
no setterinherited
copyWith → $CommandLogCopyWith<CommandLog>
Create a copy of CommandLog with the given fields replaced by the non-null parameter values.
no setterinherited
createdAt → int
no setterinherited
exitCode → int
no setterinherited
hashCode → int
The hash code for this object.
no setterinherited
logStderr → String
no setterinherited
logStdout → String
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
Serializes this CommandLog to a JSON map.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited